﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Controls.Charts;
using Infragistics.Controls;
using System.Collections;
using System.Globalization;
using Infragistics.Silverlight.Chart;
using System.Windows.Data;

namespace InfragisticsDataChart10_2
{
    public class UniversalDataPoint
    {
        public double XValue { get; set; }
        public double YValue { get; set; }
        public double ZValue { get; set; }
        public string Tag { get; set; }
        public string AxisXLabel { get; set; }
        public Brush Color { get; set; }
        public Thickness BorderThickness { get; set; }
        public SolidColorBrush BorderColor { get; set; }
        public Thickness BorderStyle { get; set; }
        public string ToolTip { get; set; }
        public string PopupBackgroundColor { get; set; }
        public string PopupFontColor { get; set; }
        public DateTime XDateTime { get; set; }
    }

    public class UniversalDataSeries
    {
        public List<UniversalDataPoint> Points { get; set; }
        public string Name { get; set; }

        public UniversalDataSeries()
        {
            Points = new List<UniversalDataPoint>();
        }
    }

    public partial class MainPage : UserControl
    {
        FrameworkElement _chartControl;
        private Infragistics.Controls.Charts.Legend _legend = null;
        public List<string> Labels = new List<string>();

        public void CreateDataChart()
        {
            _chartControl = new XamDataChart();
            ( ( XamDataChart )_chartControl ).Padding = new Thickness( 0, 20, 20, 0 );
            _chartControl.Width = 300;
            _chartControl.Height = 300;

            LayoutRoot.Children.Add( _chartControl );
        }

        public void CreateDataChartData()
        {
            List<List<string>> dims = new List<List<string>>();

            for ( int i = 0; i < 100; i++ )
            {
                List<string> currentDims = new List<string>();
                dims.Add( currentDims );
                for ( int j = 0; j < 100; j++ )
                {
                    string dimString = "Some long Dimension " + j.ToString();
                    dims[ i ].Add( dimString );
                }
            }

            //dims.Add( new List<string> { "Some long dimension 1", "Some long dimension 2", "Some long dimension 3", "Some long dimension 4", "Some long dimension 5", "Some long dimension 6" } );
            //dims.Add( new List<string> { "Some long dimension 1", "Some long dimension 2", "Some long dimension 5", "Some long dimension 6" } );
            //dims.Add( new List<string> { "Some long dimension 1", "Some long dimension 2", "Some long dimension 3", "Some long dimension 6" } );

            List<string> FullLabels = new List<string>( dims[ 0 ] );

            XamDataChart xdc = ( ( XamDataChart )_chartControl );
            xdc.Series.Clear();
            xdc.Axes.Clear();

            List<UniversalDataSeries> series = new List<UniversalDataSeries>();
            List<DateTime> dates = new List<DateTime>();

            for ( int i = 0; i < dims.Count; i++ )
            {
                List<string> currentLabels = new List<string>( FullLabels );
                
                UniversalDataSeries serie = new UniversalDataSeries();
                serie.Name = "serie " + i.ToString();

                for ( int j = 0; j < dims[ i ].Count; j++ )
                {
                    UniversalDataPoint point = new UniversalDataPoint();
                    point.YValue = i * 10 + j;

                    point.XValue = dims[ 0 ].IndexOf( dims[ i ][ j ] );
                    Labels.Add( dims[ i ][ j ] );

                    string label = dims[ i ][ j ];
                    point.AxisXLabel = label;

                    currentLabels.Remove( point.AxisXLabel );

                    serie.Points.Add( point );
                }

                foreach ( string label in currentLabels )
                {
                    UniversalDataPoint pnt = new UniversalDataPoint();
                    pnt.AxisXLabel = label;

                    pnt.YValue = double.NaN;

                    serie.Points.Insert( FullLabels.IndexOf( label ), pnt );
                }

                series.Add( serie );
            }

            _chartControl.DataContext = series;

            CategoryXAxis catXAxis = null;

            catXAxis = new CategoryXAxis();
            catXAxis.ItemsSource = (IEnumerable)dims[ 0 ];
            catXAxis.Label = "{}";
            catXAxis.LabelSettings.Extent = 55;
            catXAxis.LabelSettings.Location = AxisLabelsLocation.OutsideLeft;

            //NB: Try 10, 20 here, or not setting the interval at all.
            catXAxis.Interval = 30;

            xdc.Axes.Add( catXAxis );

            // YAxis
            NumericYAxis xmYAxis = new NumericYAxis();
            xmYAxis.LabelSettings.FontSize = 10;
            xmYAxis.LabelSettings.Extent = 55;
            xmYAxis.LabelSettings.Location = AxisLabelsLocation.OutsideLeft;
            xmYAxis.LabelSettings.HorizontalAlignment = System.Windows.HorizontalAlignment.Right;
            xmYAxis.LabelSettings.Padding = new Thickness( 0, 0, 3, 0 );

            xdc.Axes.Add( xmYAxis );

            foreach ( UniversalDataSeries uds in series )
            {
                if ( uds.Points.Count > 1 )
                {
                    LineSeries xmSeries = new LineSeries();
                    //xmSeries.XMemberPath = "XValue";
                    //xmSeries.YMemberPath = "YValue";
                    xmSeries.ValueMemberPath = "YValue";

                    xmSeries.XAxis = catXAxis;
                    xmSeries.YAxis = xmYAxis;
                    xmSeries.Name = uds.Name == "" ? "-" : uds.Name;
                    xmSeries.MarkerType = Infragistics.Controls.Charts.MarkerType.Circle;
                    xmSeries.Brush = null;
                    xmSeries.ItemsSource = ( IEnumerable )uds.Points;
                    xmSeries.ToolTip = xmSeries.Name;
                    xmSeries.UnknownValuePlotting = UnknownValuePlotting.LinearInterpolate;

                    xmSeries.Legend = _legend;
                    xmSeries.Title = xmSeries.Name;

                    xdc.Series.Add( xmSeries );
                }
            }
        }

        public MainPage()
        {
            InitializeComponent();

            CreateDataChart();
            CreateDataChartData();
        }
    }
}